@@ -1,4 +1,4 @@
-"""Custom classes and mixins for Django admins"""
+"""Custom classes and mixins for Django admins."""
 
 
 # Django
@@ -7,46 +7,46 @@ from django.http.request import HttpRequest
 
 
 class CannotAddMixin:
-    """Prevents user from adding new items through the admin interface"""
+    """Prevents user from adding new items through the admin interface."""
 
     @staticmethod
     def has_add_permission(request: HttpRequest) -> bool:
-        """Cannot add new items"""
+        """Cannot add new items."""
         return False
 
 
 class CannotDeleteMixin:
-    """Prevents user from deleting items through the admin interface"""
+    """Prevents user from deleting items through the admin interface."""
 
     @staticmethod
     def has_delete_permission(request: HttpRequest, obj: Model = None) -> bool:
-        """Cannot delete items"""
+        """Cannot delete items."""
         return False
 
 
 class CannotEditMixin:
-    """Prevents user from editing items through the admin interface"""
+    """Prevents user from editing items through the admin interface."""
 
     @staticmethod
     def has_change_permission(request: HttpRequest, obj: Model = None) -> bool:
-        """Cannot update items"""
+        """Cannot update items."""
         return False
 
 
 class CannotViewMixin:
-    """Prevents user from viewing items through the admin interface"""
+    """Prevents user from viewing items through the admin interface."""
 
     @staticmethod
     def has_view_permission(request: HttpRequest, obj: Model = None) -> bool:
-        """Cannot delete items"""
+        """Cannot delete items."""
         return False
 
 
 class ForbiddenMixin(
     CannotAddMixin, CannotDeleteMixin, CannotEditMixin, CannotViewMixin
 ):
-    """Admin with no CRUD permissions"""
+    """Admin with no CRUD permissions."""
 
 
 class ReadOnlyMixin(CannotAddMixin, CannotDeleteMixin, CannotEditMixin):
-    """Admin with read-only permissions"""
+    """Admin with read-only permissions."""
