@@ -1,4 +1,4 @@
-"""Utility functions for managing files and folders"""
+"""Utility functions for managing files and folders."""
 
 
 # Built-in
@@ -11,7 +11,7 @@ from typing import Union
 def convert_size(
     size: Union[int, float], input_units: str = "B", output_units: str = "KB"
 ) -> float:
-    """Converts bytes from one unit to another, rounded up to 2 decimals"""
+    """Converts bytes from one unit to another, rounded up to 2 decimals."""
     units = ["B", "KB", "MB", "GB", "TB", "PB", "EB", "ZB", "YB"]
     # Errors
     if input_units not in units:
@@ -29,24 +29,24 @@ def convert_size(
     output_index = units.index(output_units)
     n = output_index - input_index
     # Maths
-    output_size = round(size / (1024 ** n), 2)
+    output_size = round(size / (1024**n), 2)
     return output_size
 
 
 def create_dirs(*paths: str) -> None:
-    """For each given folder path, check if it exists. If not, it will create it"""
+    """Recursively creates missing folder paths."""
     for path in paths:
         if not os.path.exists(path):
             os.makedirs(path)
 
 
 def decode_file(contents: str) -> io.BytesIO:
-    """Decodes raw file contents and returns it"""
+    """Decodes raw file contents and returns it."""
     content_type, content_string = contents.split(",")
     return io.BytesIO(base64.b64decode(content_string))
 
 
 def get_size(path: str, output_units: str = "KB") -> float:
-    """Returns the size of a file, in the desired byte unit"""
+    """Returns the size of a file, in the desired byte unit."""
     byte_size = os.path.getsize(path)
     return convert_size(byte_size, output_units=output_units)
